import theme from './theme'
import css from 'styled-jsx/css'

const GlobalStyle = css.global`
  /* normalize.css is imported in meta.js */

  @import url('https://fonts.googleapis.com/css?family=Roboto+Mono:300|Roboto:300,900&display=swap');

  /* Use border-box sizing instead of context-box.
   This includes border and padding in the calculation.

   Also define a default font. */
  html {
    box-sizing: border-box;
    font-family: 'Roboto', sans-serif;
    font-weight: 300;
    /*font-size: 12px;*/
  }

  *,
  *:before,
  *:after {
    box-sizing: inherit;
  }

  #__next {
    display: grid;
    grid-template-areas:
      'header'
      'main'
      'footer';
    grid-template-rows: auto 1fr minmax(140px, auto);

    min-height: 100vh;

    background: ${theme.colors.offWhite};
    color: ${theme.colors.black};
    box-shadow: ${theme.bs};
  }

  @media (min-width: 500px) {
    body #__next {
      grid-template-areas:
        'header header'
        'main main'
        'footer footer';
      grid-template-columns: auto 1fr;
      grid-template-rows: auto 1fr minmax(75px, auto);
    }
  }

  header {
    grid-area: header;
  }
  main {
    grid-area: main;
  }
  footer {
    grid-area: footer;
  }

  /* Use bold font for headers */
  h1,
  h2,
  h3,
  h4,
  h5,
  h6 {
    font-weight: 900;
    color: ${theme.colors.darkerblue};
  }

  /* Use monospace font for pre */
  pre {
    font-family: 'Roboto Mono', monospace;
  }

  form * {
    font-size: 120%;
    padding: 0.3em 0.8em;
    margin: 0.8em auto;
  }

  form label {
    display: none;
  }
  form input {
    display: block;
    width: 100%;
    border: 2px solid ${theme.colors.darkerblue}00;
    color: ${theme.colors.darkerblue};
    background-color: ${theme.colors.darkerblue}27;
    transition: all 250ms ease-in-out;
  }
  form input:focus {
    color: ${theme.colors.blue};
    background-color: ${theme.colors.blue}15;
    border-bottom: 2px solid ${theme.colors.blue}44;
  }

  form button {
    display: block;
    border: none;
    background-color: ${theme.colors.darkerblue};
    color: ${theme.colors.offWhite};
  }
`

export default GlobalStyle
