import { createContext, FunctionComponent } from 'react'
import {
  useCurrentUserQuery,
  useUserLogoutMutation,
  useUserLoginMutation,
  CurrentUserDocument,
  TrainingsDocument,
} from '../gql'

interface IUserContext {
  user?: ReturnType<typeof useCurrentUserQuery>
  login?: ReturnType<typeof useUserLoginMutation>
  logout?: ReturnType<typeof useUserLogoutMutation>
}

export const UserContext = createContext<IUserContext>({})

export const UserProvider: FunctionComponent = ({ children }) => {
  const user = useCurrentUserQuery({ fetchPolicy: 'network-only' })
  const logout = useUserLogoutMutation({
    refetchQueries: [{ query: CurrentUserDocument }, { query: TrainingsDocument }],
  })
  const login = useUserLoginMutation({
    refetchQueries: [{ query: CurrentUserDocument }, { query: TrainingsDocument }],
  })
  return <UserContext.Provider value={{ user, login, logout }}>{children}</UserContext.Provider>
}
